<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Jeditjaw Formola Riċevituri");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Jeditjaw Formola Riċevituri");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "formola Paġna");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Inti tista &#39;tistabbilixxi aktar minn persuna waħda minn tissepara l-emails ma virgoli.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Iffrankar riċevitur ...");
define('VIEW_FORM_TABLES_HEADING', "Ara Tabelli tal-Formola");
define('VIEW_FORM_TABLES_BTN', "Ara Tabelli tal-Formola");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Agħżel Tabelli biex Jaraw");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtru Aqra Messaġġi");
?>